==> jc-1.4.0.tar.gz: javax/security/cert/CertificateException.h <==
// public class javax.security.cert.CertificateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8a16a5ccc9026182 javax_security_cert_CertificateException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_cert_CertificateException_H_
#define _JC_javax_security_cert_CertificateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_cert_CertificateException$sub_refs	_jc_javax_security_cert_CertificateException$sub_refs;
typedef struct _jc_javax_security_cert_CertificateException$sub_nonrefs	_jc_javax_security_cert_CertificateException$sub_nonrefs;
typedef struct _jc_javax_security_cert_CertificateException$refs	_jc_javax_security_cert_CertificateException$refs;
typedef struct _jc_javax_security_cert_CertificateException$nonrefs	_jc_javax_security_cert_CertificateException$nonrefs;
typedef struct _jc_javax_security_cert_CertificateException$object	_jc_javax_security_cert_CertificateException$object;

typedef const struct _jc_javax_security_cert_CertificateException$vmethods	_jc_javax_security_cert_CertificateException$vmethods;
typedef const struct _jc_javax_security_cert_CertificateException$vtable	_jc_javax_security_cert_CertificateException$vtable;
typedef const struct _jc_javax_security_cert_CertificateException$vtype	_jc_javax_security_cert_CertificateException$vtype;

// Constructors
extern void _jc_javax_security_cert_CertificateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_CertificateException$object *);
extern void _jc_javax_security_cert_CertificateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_cert_CertificateException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_javax_security_cert_CertificateException$vmethods {
};

// Vtable
struct _jc_javax_security_cert_CertificateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_cert_CertificateException$vmethods	javax_security_cert_CertificateException;
};

// Vtype
struct _jc_javax_security_cert_CertificateException$vtype {
	_jc_type			type;
	_jc_javax_security_cert_CertificateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_CertificateException$refs {
    _jc_javax_security_cert_CertificateException$sub_refs	javax_security_cert_CertificateException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_CertificateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_cert_CertificateException$sub_nonrefs	javax_security_cert_CertificateException;
};

// Object instance structure
struct _jc_javax_security_cert_CertificateException$object {
	_jc_javax_security_cert_CertificateException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_CertificateException$vtype	*vtype;
	_jc_javax_security_cert_CertificateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_CertificateException$vtype _jc_javax_security_cert_CertificateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_CertificateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_CertificateException$class_object;

#endif	/* _JC_javax_security_cert_CertificateException_H_ */

==> jc-1.4.6.tar.gz: javax/security/cert/CertificateException.h <==
// public class javax.security.cert.CertificateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 8a16a5ccc9026182 javax_security_cert_CertificateException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_security_cert_CertificateException_H_
#define _JC_javax_security_cert_CertificateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_security_cert_CertificateException$sub_refs	_jc_javax_security_cert_CertificateException$sub_refs;
typedef struct _jc_javax_security_cert_CertificateException$sub_nonrefs	_jc_javax_security_cert_CertificateException$sub_nonrefs;
typedef struct _jc_javax_security_cert_CertificateException$refs	_jc_javax_security_cert_CertificateException$refs;
typedef struct _jc_javax_security_cert_CertificateException$nonrefs	_jc_javax_security_cert_CertificateException$nonrefs;
typedef struct _jc_javax_security_cert_CertificateException$object	_jc_javax_security_cert_CertificateException$object;

typedef const struct _jc_javax_security_cert_CertificateException$vmethods	_jc_javax_security_cert_CertificateException$vmethods;
typedef const struct _jc_javax_security_cert_CertificateException$vtable	_jc_javax_security_cert_CertificateException$vtable;
typedef const struct _jc_javax_security_cert_CertificateException$vtype	_jc_javax_security_cert_CertificateException$vtype;

// Constructors
extern void _jc_javax_security_cert_CertificateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_cert_CertificateException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_security_cert_CertificateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_security_cert_CertificateException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_cert_CertificateException$vmethods {
};

// Vtable
struct _jc_javax_security_cert_CertificateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_security_cert_CertificateException$vmethods	javax_security_cert_CertificateException;
};

// Vtype
struct _jc_javax_security_cert_CertificateException$vtype {
	_jc_type			type;
	_jc_javax_security_cert_CertificateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_cert_CertificateException$refs {
    _jc_javax_security_cert_CertificateException$sub_refs	javax_security_cert_CertificateException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_cert_CertificateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_cert_CertificateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_security_cert_CertificateException$sub_nonrefs	javax_security_cert_CertificateException;
};

// Object instance structure
struct _jc_javax_security_cert_CertificateException$object {
	_jc_javax_security_cert_CertificateException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_cert_CertificateException$vtype	*vtype;
	_jc_javax_security_cert_CertificateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_cert_CertificateException$vtype _jc_javax_security_cert_CertificateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_cert_CertificateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_cert_CertificateException$class_object;

#endif	/* _JC_javax_security_cert_CertificateException_H_ */
